# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/common/matcher/v4alpha/matcher.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import extension_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from envoy.type.matcher.v4alpha import string_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/common/matcher/v4alpha/matcher.proto',
  package='envoy.config.common.matcher.v4alpha',
  syntax='proto3',
  serialized_options=b'\n1io.envoyproxy.envoy.config.common.matcher.v4alphaB\014MatcherProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1envoy/config/common/matcher/v4alpha/matcher.proto\x12#envoy.config.common.matcher.v4alpha\x1a)envoy/config/core/v4alpha/extension.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\'envoy/type/matcher/v4alpha/string.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcc\x14\n\x07Matcher\x12P\n\x0cmatcher_list\x18\x01 \x01(\x0b\x32\x38.envoy.config.common.matcher.v4alpha.Matcher.MatcherListH\x00\x12P\n\x0cmatcher_tree\x18\x02 \x01(\x0b\x32\x38.envoy.config.common.matcher.v4alpha.Matcher.MatcherTreeH\x00\x12I\n\x0bon_no_match\x18\x03 \x01(\x0b\x32\x34.envoy.config.common.matcher.v4alpha.Matcher.OnMatch\x1a\xd5\x01\n\x07OnMatch\x12?\n\x07matcher\x18\x01 \x01(\x0b\x32,.envoy.config.common.matcher.v4alpha.MatcherH\x00\x12\x41\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigH\x00:5\x9a\xc5\x88\x1e\x30\n.envoy.config.common.matcher.v3.Matcher.OnMatchB\x0f\n\x08on_match\x12\x03\xf8\x42\x01\x1a\xf2\n\n\x0bMatcherList\x12\x61\n\x08matchers\x18\x01 \x03(\x0b\x32\x45.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xb8\x07\n\tPredicate\x12n\n\x10single_predicate\x18\x01 \x01(\x0b\x32R.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicateH\x00\x12\x66\n\nor_matcher\x18\x02 \x01(\x0b\x32P.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateListH\x00\x12g\n\x0b\x61nd_matcher\x18\x03 \x01(\x0b\x32P.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateListH\x00\x1a\xcb\x02\n\x0fSinglePredicate\x12H\n\x05input\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12@\n\x0bvalue_match\x18\x02 \x01(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcherH\x00\x12G\n\x0c\x63ustom_match\x18\x03 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigH\x00:S\x9a\xc5\x88\x1eN\nLenvoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.SinglePredicateB\x0e\n\x07matcher\x12\x03\xf8\x42\x01\x1a\xc3\x01\n\rPredicateList\x12_\n\tpredicate\x18\x01 \x03(\x0b\x32\x42.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.PredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:Q\x9a\xc5\x88\x1eL\nJenvoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.PredicateList:C\x9a\xc5\x88\x1e>\n<envoy.config.common.matcher.v3.Matcher.MatcherList.PredicateB\x11\n\nmatch_type\x12\x03\xf8\x42\x01\x1a\x89\x02\n\x0c\x46ieldMatcher\x12_\n\tpredicate\x18\x01 \x01(\x0b\x32\x42.envoy.config.common.matcher.v4alpha.Matcher.MatcherList.PredicateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12P\n\x08on_match\x18\x02 \x01(\x0b\x32\x34.envoy.config.common.matcher.v4alpha.Matcher.OnMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:F\x9a\xc5\x88\x1e\x41\n?envoy.config.common.matcher.v3.Matcher.MatcherList.FieldMatcher:9\x9a\xc5\x88\x1e\x34\n2envoy.config.common.matcher.v3.Matcher.MatcherList\x1a\xc0\x05\n\x0bMatcherTree\x12H\n\x05input\x18\x01 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\\\n\x0f\x65xact_match_map\x18\x02 \x01(\x0b\x32\x41.envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMapH\x00\x12]\n\x10prefix_match_map\x18\x03 \x01(\x0b\x32\x41.envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMapH\x00\x12G\n\x0c\x63ustom_match\x18\x04 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfigH\x00\x1a\x93\x02\n\x08MatchMap\x12\x61\n\x03map\x18\x01 \x03(\x0b\x32J.envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntryB\x08\xfa\x42\x05\x9a\x01\x02\x08\x01\x1a`\n\x08MapEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.envoy.config.common.matcher.v4alpha.Matcher.OnMatch:\x02\x38\x01:B\x9a\xc5\x88\x1e=\n;envoy.config.common.matcher.v3.Matcher.MatcherTree.MatchMap:9\x9a\xc5\x88\x1e\x34\n2envoy.config.common.matcher.v3.Matcher.MatcherTreeB\x10\n\ttree_type\x12\x03\xf8\x42\x01:-\x9a\xc5\x88\x1e(\n&envoy.config.common.matcher.v3.MatcherB\x13\n\x0cmatcher_type\x12\x03\xf8\x42\x01\"\xbf\x08\n\x0eMatchPredicate\x12P\n\x08or_match\x18\x01 \x01(\x0b\x32<.envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSetH\x00\x12Q\n\tand_match\x18\x02 \x01(\x0b\x32<.envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSetH\x00\x12H\n\tnot_match\x18\x03 \x01(\x0b\x32\x33.envoy.config.common.matcher.v4alpha.MatchPredicateH\x00\x12\x1c\n\tany_match\x18\x04 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12[\n\x1ahttp_request_headers_match\x18\x05 \x01(\x0b\x32\x35.envoy.config.common.matcher.v4alpha.HttpHeadersMatchH\x00\x12\\\n\x1bhttp_request_trailers_match\x18\x06 \x01(\x0b\x32\x35.envoy.config.common.matcher.v4alpha.HttpHeadersMatchH\x00\x12\\\n\x1bhttp_response_headers_match\x18\x07 \x01(\x0b\x32\x35.envoy.config.common.matcher.v4alpha.HttpHeadersMatchH\x00\x12]\n\x1chttp_response_trailers_match\x18\x08 \x01(\x0b\x32\x35.envoy.config.common.matcher.v4alpha.HttpHeadersMatchH\x00\x12\x64\n\x1fhttp_request_generic_body_match\x18\t \x01(\x0b\x32\x39.envoy.config.common.matcher.v4alpha.HttpGenericBodyMatchH\x00\x12\x65\n http_response_generic_body_match\x18\n \x01(\x0b\x32\x39.envoy.config.common.matcher.v4alpha.HttpGenericBodyMatchH\x00\x1a\x97\x01\n\x08MatchSet\x12L\n\x05rules\x18\x01 \x03(\x0b\x32\x33.envoy.config.common.matcher.v4alpha.MatchPredicateB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:=\x9a\xc5\x88\x1e\x38\n6envoy.config.common.matcher.v3.MatchPredicate.MatchSet:4\x9a\xc5\x88\x1e/\n-envoy.config.common.matcher.v3.MatchPredicateB\x0b\n\x04rule\x12\x03\xf8\x42\x01\"\x86\x01\n\x10HttpHeadersMatch\x12:\n\x07headers\x18\x01 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher:6\x9a\xc5\x88\x1e\x31\n/envoy.config.common.matcher.v3.HttpHeadersMatch\"\x80\x03\n\x14HttpGenericBodyMatch\x12\x13\n\x0b\x62ytes_limit\x18\x01 \x01(\r\x12\x66\n\x08patterns\x18\x02 \x03(\x0b\x32J.envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatchB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xae\x01\n\x10GenericTextMatch\x12\x1f\n\x0cstring_match\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x1f\n\x0c\x62inary_match\x18\x02 \x01(\x0c\x42\x07\xfa\x42\x04z\x02\x10\x01H\x00:K\x9a\xc5\x88\x1e\x46\nDenvoy.config.common.matcher.v3.HttpGenericBodyMatch.GenericTextMatchB\x0b\n\x04rule\x12\x03\xf8\x42\x01::\x9a\xc5\x88\x1e\x35\n3envoy.config.common.matcher.v3.HttpGenericBodyMatchBK\n1io.envoyproxy.envoy.config.common.matcher.v4alphaB\x0cMatcherProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_MATCHER_ONMATCH = _descriptor.Descriptor(
  name='OnMatch',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.OnMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matcher', full_name='envoy.config.common.matcher.v4alpha.Matcher.OnMatch.matcher', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='envoy.config.common.matcher.v4alpha.Matcher.OnMatch.action', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.config.common.matcher.v3.Matcher.OnMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='on_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.OnMatch.on_match',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=568,
  serialized_end=781,
)

_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE = _descriptor.Descriptor(
  name='SinglePredicate',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate.value_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate.custom_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036N\nLenvoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.SinglePredicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='matcher', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate.matcher',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1234,
  serialized_end=1565,
)

_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST = _descriptor.Descriptor(
  name='PredicateList',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicate', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateList.predicate', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036L\nJenvoy.config.common.matcher.v3.Matcher.MatcherList.Predicate.PredicateList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1763,
)

_MATCHER_MATCHERLIST_PREDICATE = _descriptor.Descriptor(
  name='Predicate',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='single_predicate', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.single_predicate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='or_matcher', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.or_matcher', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='and_matcher', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.and_matcher', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE, _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.config.common.matcher.v3.Matcher.MatcherList.Predicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='match_type', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.match_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=899,
  serialized_end=1851,
)

_MATCHER_MATCHERLIST_FIELDMATCHER = _descriptor.Descriptor(
  name='FieldMatcher',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='predicate', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcher.predicate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcher.on_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.config.common.matcher.v3.Matcher.MatcherList.FieldMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1854,
  serialized_end=2119,
)

_MATCHER_MATCHERLIST = _descriptor.Descriptor(
  name='MatcherList',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchers', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherList.matchers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_MATCHERLIST_PREDICATE, _MATCHER_MATCHERLIST_FIELDMATCHER, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.common.matcher.v3.Matcher.MatcherList',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=2178,
)

_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY = _descriptor.Descriptor(
  name='MapEntry',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2644,
  serialized_end=2740,
)

_MATCHER_MATCHERTREE_MATCHMAP = _descriptor.Descriptor(
  name='MatchMap',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='map', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\232\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.config.common.matcher.v3.Matcher.MatcherTree.MatchMap',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2533,
  serialized_end=2808,
)

_MATCHER_MATCHERTREE = _descriptor.Descriptor(
  name='MatcherTree',
  full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exact_match_map', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.exact_match_map', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix_match_map', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.prefix_match_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.custom_match', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_MATCHERTREE_MATCHMAP, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.config.common.matcher.v3.Matcher.MatcherTree',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tree_type', full_name='envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.tree_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2181,
  serialized_end=2885,
)

_MATCHER = _descriptor.Descriptor(
  name='Matcher',
  full_name='envoy.config.common.matcher.v4alpha.Matcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matcher_list', full_name='envoy.config.common.matcher.v4alpha.Matcher.matcher_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher_tree', full_name='envoy.config.common.matcher.v4alpha.Matcher.matcher_tree', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_no_match', full_name='envoy.config.common.matcher.v4alpha.Matcher.on_no_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHER_ONMATCH, _MATCHER_MATCHERLIST, _MATCHER_MATCHERTREE, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.config.common.matcher.v3.Matcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='matcher_type', full_name='envoy.config.common.matcher.v4alpha.Matcher.matcher_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=317,
  serialized_end=2953,
)


_MATCHPREDICATE_MATCHSET = _descriptor.Descriptor(
  name='MatchSet',
  full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSet.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.config.common.matcher.v3.MatchPredicate.MatchSet',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3825,
  serialized_end=3976,
)

_MATCHPREDICATE = _descriptor.Descriptor(
  name='MatchPredicate',
  full_name='envoy.config.common.matcher.v4alpha.MatchPredicate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='or_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.or_match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='and_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.and_match', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.not_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='any_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.any_match', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_headers_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_request_headers_match', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_trailers_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_request_trailers_match', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_headers_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_response_headers_match', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_trailers_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_response_trailers_match', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_request_generic_body_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_request_generic_body_match', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_response_generic_body_match', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.http_response_generic_body_match', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATCHPREDICATE_MATCHSET, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.common.matcher.v3.MatchPredicate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.config.common.matcher.v4alpha.MatchPredicate.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2956,
  serialized_end=4043,
)


_HTTPHEADERSMATCH = _descriptor.Descriptor(
  name='HttpHeadersMatch',
  full_name='envoy.config.common.matcher.v4alpha.HttpHeadersMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.config.common.matcher.v4alpha.HttpHeadersMatch.headers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.config.common.matcher.v3.HttpHeadersMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4046,
  serialized_end=4180,
)


_HTTPGENERICBODYMATCH_GENERICTEXTMATCH = _descriptor.Descriptor(
  name='GenericTextMatch',
  full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_match', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch.string_match', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_match', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch.binary_match', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004z\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036F\nDenvoy.config.common.matcher.v3.HttpGenericBodyMatch.GenericTextMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=4333,
  serialized_end=4507,
)

_HTTPGENERICBODYMATCH = _descriptor.Descriptor(
  name='HttpGenericBodyMatch',
  full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes_limit', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.bytes_limit', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='patterns', full_name='envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.patterns', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HTTPGENERICBODYMATCH_GENERICTEXTMATCH, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.config.common.matcher.v3.HttpGenericBodyMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4183,
  serialized_end=4567,
)

_MATCHER_ONMATCH.fields_by_name['matcher'].message_type = _MATCHER
_MATCHER_ONMATCH.fields_by_name['action'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_ONMATCH.containing_type = _MATCHER
_MATCHER_ONMATCH.oneofs_by_name['on_match'].fields.append(
  _MATCHER_ONMATCH.fields_by_name['matcher'])
_MATCHER_ONMATCH.fields_by_name['matcher'].containing_oneof = _MATCHER_ONMATCH.oneofs_by_name['on_match']
_MATCHER_ONMATCH.oneofs_by_name['on_match'].fields.append(
  _MATCHER_ONMATCH.fields_by_name['action'])
_MATCHER_ONMATCH.fields_by_name['action'].containing_oneof = _MATCHER_ONMATCH.oneofs_by_name['on_match']
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['input'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['value_match'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._STRINGMATCHER
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['custom_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.containing_type = _MATCHER_MATCHERLIST_PREDICATE
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['value_match'])
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['value_match'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher']
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['custom_match'])
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['custom_match'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher']
_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST.fields_by_name['predicate'].message_type = _MATCHER_MATCHERLIST_PREDICATE
_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST.containing_type = _MATCHER_MATCHERLIST_PREDICATE
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['single_predicate'].message_type = _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['or_matcher'].message_type = _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['and_matcher'].message_type = _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST
_MATCHER_MATCHERLIST_PREDICATE.containing_type = _MATCHER_MATCHERLIST
_MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE.fields_by_name['single_predicate'])
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['single_predicate'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']
_MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE.fields_by_name['or_matcher'])
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['or_matcher'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']
_MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type'].fields.append(
  _MATCHER_MATCHERLIST_PREDICATE.fields_by_name['and_matcher'])
_MATCHER_MATCHERLIST_PREDICATE.fields_by_name['and_matcher'].containing_oneof = _MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']
_MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['predicate'].message_type = _MATCHER_MATCHERLIST_PREDICATE
_MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['on_match'].message_type = _MATCHER_ONMATCH
_MATCHER_MATCHERLIST_FIELDMATCHER.containing_type = _MATCHER_MATCHERLIST
_MATCHER_MATCHERLIST.fields_by_name['matchers'].message_type = _MATCHER_MATCHERLIST_FIELDMATCHER
_MATCHER_MATCHERLIST.containing_type = _MATCHER
_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY.fields_by_name['value'].message_type = _MATCHER_ONMATCH
_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY.containing_type = _MATCHER_MATCHERTREE_MATCHMAP
_MATCHER_MATCHERTREE_MATCHMAP.fields_by_name['map'].message_type = _MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY
_MATCHER_MATCHERTREE_MATCHMAP.containing_type = _MATCHER_MATCHERTREE
_MATCHER_MATCHERTREE.fields_by_name['input'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_MATCHERTREE.fields_by_name['exact_match_map'].message_type = _MATCHER_MATCHERTREE_MATCHMAP
_MATCHER_MATCHERTREE.fields_by_name['prefix_match_map'].message_type = _MATCHER_MATCHERTREE_MATCHMAP
_MATCHER_MATCHERTREE.fields_by_name['custom_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_MATCHER_MATCHERTREE.containing_type = _MATCHER
_MATCHER_MATCHERTREE.oneofs_by_name['tree_type'].fields.append(
  _MATCHER_MATCHERTREE.fields_by_name['exact_match_map'])
_MATCHER_MATCHERTREE.fields_by_name['exact_match_map'].containing_oneof = _MATCHER_MATCHERTREE.oneofs_by_name['tree_type']
_MATCHER_MATCHERTREE.oneofs_by_name['tree_type'].fields.append(
  _MATCHER_MATCHERTREE.fields_by_name['prefix_match_map'])
_MATCHER_MATCHERTREE.fields_by_name['prefix_match_map'].containing_oneof = _MATCHER_MATCHERTREE.oneofs_by_name['tree_type']
_MATCHER_MATCHERTREE.oneofs_by_name['tree_type'].fields.append(
  _MATCHER_MATCHERTREE.fields_by_name['custom_match'])
_MATCHER_MATCHERTREE.fields_by_name['custom_match'].containing_oneof = _MATCHER_MATCHERTREE.oneofs_by_name['tree_type']
_MATCHER.fields_by_name['matcher_list'].message_type = _MATCHER_MATCHERLIST
_MATCHER.fields_by_name['matcher_tree'].message_type = _MATCHER_MATCHERTREE
_MATCHER.fields_by_name['on_no_match'].message_type = _MATCHER_ONMATCH
_MATCHER.oneofs_by_name['matcher_type'].fields.append(
  _MATCHER.fields_by_name['matcher_list'])
_MATCHER.fields_by_name['matcher_list'].containing_oneof = _MATCHER.oneofs_by_name['matcher_type']
_MATCHER.oneofs_by_name['matcher_type'].fields.append(
  _MATCHER.fields_by_name['matcher_tree'])
_MATCHER.fields_by_name['matcher_tree'].containing_oneof = _MATCHER.oneofs_by_name['matcher_type']
_MATCHPREDICATE_MATCHSET.fields_by_name['rules'].message_type = _MATCHPREDICATE
_MATCHPREDICATE_MATCHSET.containing_type = _MATCHPREDICATE
_MATCHPREDICATE.fields_by_name['or_match'].message_type = _MATCHPREDICATE_MATCHSET
_MATCHPREDICATE.fields_by_name['and_match'].message_type = _MATCHPREDICATE_MATCHSET
_MATCHPREDICATE.fields_by_name['not_match'].message_type = _MATCHPREDICATE
_MATCHPREDICATE.fields_by_name['http_request_headers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_request_trailers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_response_headers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_response_trailers_match'].message_type = _HTTPHEADERSMATCH
_MATCHPREDICATE.fields_by_name['http_request_generic_body_match'].message_type = _HTTPGENERICBODYMATCH
_MATCHPREDICATE.fields_by_name['http_response_generic_body_match'].message_type = _HTTPGENERICBODYMATCH
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['or_match'])
_MATCHPREDICATE.fields_by_name['or_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['and_match'])
_MATCHPREDICATE.fields_by_name['and_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['not_match'])
_MATCHPREDICATE.fields_by_name['not_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['any_match'])
_MATCHPREDICATE.fields_by_name['any_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_headers_match'])
_MATCHPREDICATE.fields_by_name['http_request_headers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_trailers_match'])
_MATCHPREDICATE.fields_by_name['http_request_trailers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_headers_match'])
_MATCHPREDICATE.fields_by_name['http_response_headers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_trailers_match'])
_MATCHPREDICATE.fields_by_name['http_response_trailers_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_request_generic_body_match'])
_MATCHPREDICATE.fields_by_name['http_request_generic_body_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_MATCHPREDICATE.oneofs_by_name['rule'].fields.append(
  _MATCHPREDICATE.fields_by_name['http_response_generic_body_match'])
_MATCHPREDICATE.fields_by_name['http_response_generic_body_match'].containing_oneof = _MATCHPREDICATE.oneofs_by_name['rule']
_HTTPHEADERSMATCH.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.containing_type = _HTTPGENERICBODYMATCH
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule'].fields.append(
  _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match'])
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match'].containing_oneof = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule'].fields.append(
  _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match'])
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match'].containing_oneof = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']
_HTTPGENERICBODYMATCH.fields_by_name['patterns'].message_type = _HTTPGENERICBODYMATCH_GENERICTEXTMATCH
DESCRIPTOR.message_types_by_name['Matcher'] = _MATCHER
DESCRIPTOR.message_types_by_name['MatchPredicate'] = _MATCHPREDICATE
DESCRIPTOR.message_types_by_name['HttpHeadersMatch'] = _HTTPHEADERSMATCH
DESCRIPTOR.message_types_by_name['HttpGenericBodyMatch'] = _HTTPGENERICBODYMATCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Matcher = _reflection.GeneratedProtocolMessageType('Matcher', (_message.Message,), {

  'OnMatch' : _reflection.GeneratedProtocolMessageType('OnMatch', (_message.Message,), {
    'DESCRIPTOR' : _MATCHER_ONMATCH,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.OnMatch)
    })
  ,

  'MatcherList' : _reflection.GeneratedProtocolMessageType('MatcherList', (_message.Message,), {

    'Predicate' : _reflection.GeneratedProtocolMessageType('Predicate', (_message.Message,), {

      'SinglePredicate' : _reflection.GeneratedProtocolMessageType('SinglePredicate', (_message.Message,), {
        'DESCRIPTOR' : _MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE,
        '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.SinglePredicate)
        })
      ,

      'PredicateList' : _reflection.GeneratedProtocolMessageType('PredicateList', (_message.Message,), {
        'DESCRIPTOR' : _MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST,
        '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate.PredicateList)
        })
      ,
      'DESCRIPTOR' : _MATCHER_MATCHERLIST_PREDICATE,
      '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList.Predicate)
      })
    ,

    'FieldMatcher' : _reflection.GeneratedProtocolMessageType('FieldMatcher', (_message.Message,), {
      'DESCRIPTOR' : _MATCHER_MATCHERLIST_FIELDMATCHER,
      '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList.FieldMatcher)
      })
    ,
    'DESCRIPTOR' : _MATCHER_MATCHERLIST,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherList)
    })
  ,

  'MatcherTree' : _reflection.GeneratedProtocolMessageType('MatcherTree', (_message.Message,), {

    'MatchMap' : _reflection.GeneratedProtocolMessageType('MatchMap', (_message.Message,), {

      'MapEntry' : _reflection.GeneratedProtocolMessageType('MapEntry', (_message.Message,), {
        'DESCRIPTOR' : _MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY,
        '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
        # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap.MapEntry)
        })
      ,
      'DESCRIPTOR' : _MATCHER_MATCHERTREE_MATCHMAP,
      '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherTree.MatchMap)
      })
    ,
    'DESCRIPTOR' : _MATCHER_MATCHERTREE,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher.MatcherTree)
    })
  ,
  'DESCRIPTOR' : _MATCHER,
  '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.Matcher)
  })
_sym_db.RegisterMessage(Matcher)
_sym_db.RegisterMessage(Matcher.OnMatch)
_sym_db.RegisterMessage(Matcher.MatcherList)
_sym_db.RegisterMessage(Matcher.MatcherList.Predicate)
_sym_db.RegisterMessage(Matcher.MatcherList.Predicate.SinglePredicate)
_sym_db.RegisterMessage(Matcher.MatcherList.Predicate.PredicateList)
_sym_db.RegisterMessage(Matcher.MatcherList.FieldMatcher)
_sym_db.RegisterMessage(Matcher.MatcherTree)
_sym_db.RegisterMessage(Matcher.MatcherTree.MatchMap)
_sym_db.RegisterMessage(Matcher.MatcherTree.MatchMap.MapEntry)

MatchPredicate = _reflection.GeneratedProtocolMessageType('MatchPredicate', (_message.Message,), {

  'MatchSet' : _reflection.GeneratedProtocolMessageType('MatchSet', (_message.Message,), {
    'DESCRIPTOR' : _MATCHPREDICATE_MATCHSET,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.MatchPredicate.MatchSet)
    })
  ,
  'DESCRIPTOR' : _MATCHPREDICATE,
  '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.MatchPredicate)
  })
_sym_db.RegisterMessage(MatchPredicate)
_sym_db.RegisterMessage(MatchPredicate.MatchSet)

HttpHeadersMatch = _reflection.GeneratedProtocolMessageType('HttpHeadersMatch', (_message.Message,), {
  'DESCRIPTOR' : _HTTPHEADERSMATCH,
  '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.HttpHeadersMatch)
  })
_sym_db.RegisterMessage(HttpHeadersMatch)

HttpGenericBodyMatch = _reflection.GeneratedProtocolMessageType('HttpGenericBodyMatch', (_message.Message,), {

  'GenericTextMatch' : _reflection.GeneratedProtocolMessageType('GenericTextMatch', (_message.Message,), {
    'DESCRIPTOR' : _HTTPGENERICBODYMATCH_GENERICTEXTMATCH,
    '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch.GenericTextMatch)
    })
  ,
  'DESCRIPTOR' : _HTTPGENERICBODYMATCH,
  '__module__' : 'envoy.config.common.matcher.v4alpha.matcher_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.common.matcher.v4alpha.HttpGenericBodyMatch)
  })
_sym_db.RegisterMessage(HttpGenericBodyMatch)
_sym_db.RegisterMessage(HttpGenericBodyMatch.GenericTextMatch)


DESCRIPTOR._options = None
_MATCHER_ONMATCH.oneofs_by_name['on_match']._options = None
_MATCHER_ONMATCH._options = None
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.oneofs_by_name['matcher']._options = None
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE.fields_by_name['input']._options = None
_MATCHER_MATCHERLIST_PREDICATE_SINGLEPREDICATE._options = None
_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST.fields_by_name['predicate']._options = None
_MATCHER_MATCHERLIST_PREDICATE_PREDICATELIST._options = None
_MATCHER_MATCHERLIST_PREDICATE.oneofs_by_name['match_type']._options = None
_MATCHER_MATCHERLIST_PREDICATE._options = None
_MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['predicate']._options = None
_MATCHER_MATCHERLIST_FIELDMATCHER.fields_by_name['on_match']._options = None
_MATCHER_MATCHERLIST_FIELDMATCHER._options = None
_MATCHER_MATCHERLIST.fields_by_name['matchers']._options = None
_MATCHER_MATCHERLIST._options = None
_MATCHER_MATCHERTREE_MATCHMAP_MAPENTRY._options = None
_MATCHER_MATCHERTREE_MATCHMAP.fields_by_name['map']._options = None
_MATCHER_MATCHERTREE_MATCHMAP._options = None
_MATCHER_MATCHERTREE.oneofs_by_name['tree_type']._options = None
_MATCHER_MATCHERTREE.fields_by_name['input']._options = None
_MATCHER_MATCHERTREE._options = None
_MATCHER.oneofs_by_name['matcher_type']._options = None
_MATCHER._options = None
_MATCHPREDICATE_MATCHSET.fields_by_name['rules']._options = None
_MATCHPREDICATE_MATCHSET._options = None
_MATCHPREDICATE.oneofs_by_name['rule']._options = None
_MATCHPREDICATE.fields_by_name['any_match']._options = None
_MATCHPREDICATE._options = None
_HTTPHEADERSMATCH._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.oneofs_by_name['rule']._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['string_match']._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH.fields_by_name['binary_match']._options = None
_HTTPGENERICBODYMATCH_GENERICTEXTMATCH._options = None
_HTTPGENERICBODYMATCH.fields_by_name['patterns']._options = None
_HTTPGENERICBODYMATCH._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/ext_authz/v2/ext_authz.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from envoy.api.v2.core import http_uri_pb2 as envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2
from envoy.type import http_status_pb2 as envoy_dot_type_dot_http__status__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/ext_authz/v2/ext_authz.proto',
  package='envoy.config.filter.http.ext_authz.v2',
  syntax='proto3',
  serialized_options=b'\n3io.envoyproxy.envoy.config.filter.http.ext_authz.v2B\rExtAuthzProtoP\001\362\230\376\217\005,\022*envoy.extensions.filters.http.ext_authz.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5envoy/config/filter/http/ext_authz/v2/ext_authz.proto\x12%envoy.config.filter.http.ext_authz.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/grpc_service.proto\x1a envoy/api/v2/core/http_uri.proto\x1a\x1c\x65nvoy/type/http_status.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbd\x04\n\x08\x45xtAuthz\x12\x36\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceH\x00\x12J\n\x0chttp_service\x18\x03 \x01(\x0b\x32\x32.envoy.config.filter.http.ext_authz.v2.HttpServiceH\x00\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12\x1b\n\tuse_alpha\x18\x04 \x01(\x08\x42\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12P\n\x11with_request_body\x18\x05 \x01(\x0b\x32\x35.envoy.config.filter.http.ext_authz.v2.BufferSettings\x12\x19\n\x11\x63lear_route_cache\x18\x06 \x01(\x08\x12/\n\x0fstatus_on_error\x18\x07 \x01(\x0b\x32\x16.envoy.type.HttpStatus\x12#\n\x1bmetadata_context_namespaces\x18\x08 \x03(\t\x12\x43\n\x0e\x66ilter_enabled\x18\t \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12>\n\x0f\x64\x65ny_at_disable\x18\x0b \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlag\x12 \n\x18include_peer_certificate\x18\n \x01(\x08\x42\n\n\x08services\"S\n\x0e\x42ufferSettings\x12\"\n\x11max_request_bytes\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02 \x00\x12\x1d\n\x15\x61llow_partial_message\x18\x02 \x01(\x08\"\xa4\x02\n\x0bHttpService\x12.\n\nserver_uri\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.HttpUri\x12\x13\n\x0bpath_prefix\x18\x02 \x01(\t\x12Z\n\x15\x61uthorization_request\x18\x07 \x01(\x0b\x32;.envoy.config.filter.http.ext_authz.v2.AuthorizationRequest\x12\\\n\x16\x61uthorization_response\x18\x08 \x01(\x0b\x32<.envoy.config.filter.http.ext_authz.v2.AuthorizationResponseJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\x8e\x01\n\x14\x41uthorizationRequest\x12>\n\x0f\x61llowed_headers\x18\x01 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\x12\x36\n\x0eheaders_to_add\x18\x02 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\"\xa7\x01\n\x15\x41uthorizationResponse\x12G\n\x18\x61llowed_upstream_headers\x18\x01 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\x12\x45\n\x16\x61llowed_client_headers\x18\x02 \x01(\x0b\x32%.envoy.type.matcher.ListStringMatcher\"\x9a\x01\n\x10\x45xtAuthzPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12X\n\x0e\x63heck_settings\x18\x02 \x01(\x0b\x32\x34.envoy.config.filter.http.ext_authz.v2.CheckSettingsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xb2\x01\n\rCheckSettings\x12g\n\x12\x63ontext_extensions\x18\x01 \x03(\x0b\x32K.envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry\x1a\x38\n\x16\x43ontextExtensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x80\x01\n3io.envoyproxy.envoy.config.filter.http.ext_authz.v2B\rExtAuthzProtoP\x01\xf2\x98\xfe\x8f\x05,\x12*envoy.extensions.filters.http.ext_authz.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_type_dot_http__status__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_string__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTAUTHZ = _descriptor.Descriptor(
  name='ExtAuthz',
  full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_service', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.http_service', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_allow', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.failure_mode_allow', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_alpha', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.use_alpha', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_request_body', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.with_request_body', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_route_cache', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.clear_route_cache', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status_on_error', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.status_on_error', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_context_namespaces', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.metadata_context_namespaces', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_enabled', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.filter_enabled', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deny_at_disable', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.deny_at_disable', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_peer_certificate', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.include_peer_certificate', index=10,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='services', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthz.services',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=387,
  serialized_end=960,
)


_BUFFERSETTINGS = _descriptor.Descriptor(
  name='BufferSettings',
  full_name='envoy.config.filter.http.ext_authz.v2.BufferSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_request_bytes', full_name='envoy.config.filter.http.ext_authz.v2.BufferSettings.max_request_bytes', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_partial_message', full_name='envoy.config.filter.http.ext_authz.v2.BufferSettings.allow_partial_message', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=1045,
)


_HTTPSERVICE = _descriptor.Descriptor(
  name='HttpService',
  full_name='envoy.config.filter.http.ext_authz.v2.HttpService',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_uri', full_name='envoy.config.filter.http.ext_authz.v2.HttpService.server_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_prefix', full_name='envoy.config.filter.http.ext_authz.v2.HttpService.path_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_request', full_name='envoy.config.filter.http.ext_authz.v2.HttpService.authorization_request', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_response', full_name='envoy.config.filter.http.ext_authz.v2.HttpService.authorization_response', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1048,
  serialized_end=1340,
)


_AUTHORIZATIONREQUEST = _descriptor.Descriptor(
  name='AuthorizationRequest',
  full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_headers', full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationRequest.allowed_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers_to_add', full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationRequest.headers_to_add', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1485,
)


_AUTHORIZATIONRESPONSE = _descriptor.Descriptor(
  name='AuthorizationResponse',
  full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_upstream_headers', full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationResponse.allowed_upstream_headers', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_client_headers', full_name='envoy.config.filter.http.ext_authz.v2.AuthorizationResponse.allowed_client_headers', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1488,
  serialized_end=1655,
)


_EXTAUTHZPERROUTE = _descriptor.Descriptor(
  name='ExtAuthzPerRoute',
  full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_settings', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute.check_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1658,
  serialized_end=1812,
)


_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY = _descriptor.Descriptor(
  name='ContextExtensionsEntry',
  full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1937,
  serialized_end=1993,
)

_CHECKSETTINGS = _descriptor.Descriptor(
  name='CheckSettings',
  full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='context_extensions', full_name='envoy.config.filter.http.ext_authz.v2.CheckSettings.context_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1993,
)

_EXTAUTHZ.fields_by_name['grpc_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2._GRPCSERVICE
_EXTAUTHZ.fields_by_name['http_service'].message_type = _HTTPSERVICE
_EXTAUTHZ.fields_by_name['with_request_body'].message_type = _BUFFERSETTINGS
_EXTAUTHZ.fields_by_name['status_on_error'].message_type = envoy_dot_type_dot_http__status__pb2._HTTPSTATUS
_EXTAUTHZ.fields_by_name['filter_enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFRACTIONALPERCENT
_EXTAUTHZ.fields_by_name['deny_at_disable'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFEATUREFLAG
_EXTAUTHZ.oneofs_by_name['services'].fields.append(
  _EXTAUTHZ.fields_by_name['grpc_service'])
_EXTAUTHZ.fields_by_name['grpc_service'].containing_oneof = _EXTAUTHZ.oneofs_by_name['services']
_EXTAUTHZ.oneofs_by_name['services'].fields.append(
  _EXTAUTHZ.fields_by_name['http_service'])
_EXTAUTHZ.fields_by_name['http_service'].containing_oneof = _EXTAUTHZ.oneofs_by_name['services']
_HTTPSERVICE.fields_by_name['server_uri'].message_type = envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2._HTTPURI
_HTTPSERVICE.fields_by_name['authorization_request'].message_type = _AUTHORIZATIONREQUEST
_HTTPSERVICE.fields_by_name['authorization_response'].message_type = _AUTHORIZATIONRESPONSE
_AUTHORIZATIONREQUEST.fields_by_name['allowed_headers'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONREQUEST.fields_by_name['headers_to_add'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUE
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_upstream_headers'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._LISTSTRINGMATCHER
_AUTHORIZATIONRESPONSE.fields_by_name['allowed_client_headers'].message_type = envoy_dot_type_dot_matcher_dot_string__pb2._LISTSTRINGMATCHER
_EXTAUTHZPERROUTE.fields_by_name['check_settings'].message_type = _CHECKSETTINGS
_EXTAUTHZPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTAUTHZPERROUTE.fields_by_name['disabled'])
_EXTAUTHZPERROUTE.fields_by_name['disabled'].containing_oneof = _EXTAUTHZPERROUTE.oneofs_by_name['override']
_EXTAUTHZPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTAUTHZPERROUTE.fields_by_name['check_settings'])
_EXTAUTHZPERROUTE.fields_by_name['check_settings'].containing_oneof = _EXTAUTHZPERROUTE.oneofs_by_name['override']
_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY.containing_type = _CHECKSETTINGS
_CHECKSETTINGS.fields_by_name['context_extensions'].message_type = _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY
DESCRIPTOR.message_types_by_name['ExtAuthz'] = _EXTAUTHZ
DESCRIPTOR.message_types_by_name['BufferSettings'] = _BUFFERSETTINGS
DESCRIPTOR.message_types_by_name['HttpService'] = _HTTPSERVICE
DESCRIPTOR.message_types_by_name['AuthorizationRequest'] = _AUTHORIZATIONREQUEST
DESCRIPTOR.message_types_by_name['AuthorizationResponse'] = _AUTHORIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['ExtAuthzPerRoute'] = _EXTAUTHZPERROUTE
DESCRIPTOR.message_types_by_name['CheckSettings'] = _CHECKSETTINGS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExtAuthz = _reflection.GeneratedProtocolMessageType('ExtAuthz', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZ,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.ExtAuthz)
  })
_sym_db.RegisterMessage(ExtAuthz)

BufferSettings = _reflection.GeneratedProtocolMessageType('BufferSettings', (_message.Message,), {
  'DESCRIPTOR' : _BUFFERSETTINGS,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.BufferSettings)
  })
_sym_db.RegisterMessage(BufferSettings)

HttpService = _reflection.GeneratedProtocolMessageType('HttpService', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSERVICE,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.HttpService)
  })
_sym_db.RegisterMessage(HttpService)

AuthorizationRequest = _reflection.GeneratedProtocolMessageType('AuthorizationRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONREQUEST,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.AuthorizationRequest)
  })
_sym_db.RegisterMessage(AuthorizationRequest)

AuthorizationResponse = _reflection.GeneratedProtocolMessageType('AuthorizationResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONRESPONSE,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.AuthorizationResponse)
  })
_sym_db.RegisterMessage(AuthorizationResponse)

ExtAuthzPerRoute = _reflection.GeneratedProtocolMessageType('ExtAuthzPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _EXTAUTHZPERROUTE,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.ExtAuthzPerRoute)
  })
_sym_db.RegisterMessage(ExtAuthzPerRoute)

CheckSettings = _reflection.GeneratedProtocolMessageType('CheckSettings', (_message.Message,), {

  'ContextExtensionsEntry' : _reflection.GeneratedProtocolMessageType('ContextExtensionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHECKSETTINGS_CONTEXTEXTENSIONSENTRY,
    '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.CheckSettings.ContextExtensionsEntry)
    })
  ,
  'DESCRIPTOR' : _CHECKSETTINGS,
  '__module__' : 'envoy.config.filter.http.ext_authz.v2.ext_authz_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ext_authz.v2.CheckSettings)
  })
_sym_db.RegisterMessage(CheckSettings)
_sym_db.RegisterMessage(CheckSettings.ContextExtensionsEntry)


DESCRIPTOR._options = None
_EXTAUTHZ.fields_by_name['use_alpha']._options = None
_BUFFERSETTINGS.fields_by_name['max_request_bytes']._options = None
_EXTAUTHZPERROUTE.oneofs_by_name['override']._options = None
_EXTAUTHZPERROUTE.fields_by_name['disabled']._options = None
_EXTAUTHZPERROUTE.fields_by_name['check_settings']._options = None
_CHECKSETTINGS_CONTEXTEXTENSIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v2/external_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.service.auth.v2 import attribute_context_pb2 as envoy_dot_service_dot_auth_dot_v2_dot_attribute__context__pb2
from envoy.type import http_status_pb2 as envoy_dot_type_dot_http__status__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/auth/v2/external_auth.proto',
  package='envoy.service.auth.v2',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.service.auth.v2B\021ExternalAuthProtoP\001\210\001\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)envoy/service/auth/v2/external_auth.proto\x12\x15\x65nvoy.service.auth.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a-envoy/service/auth/v2/attribute_context.proto\x1a\x1c\x65nvoy/type/http_status.proto\x1a\x17google/rpc/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"K\n\x0c\x43heckRequest\x12;\n\nattributes\x18\x01 \x01(\x0b\x32\'.envoy.service.auth.v2.AttributeContext\"\x8b\x01\n\x12\x44\x65niedHttpResponse\x12\x30\n\x06status\x18\x01 \x01(\x0b\x32\x16.envoy.type.HttpStatusB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x35\n\x07headers\x18\x02 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOption\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\"G\n\x0eOkHttpResponse\x12\x35\n\x07headers\x18\x02 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOption\"\xc8\x01\n\rCheckResponse\x12\"\n\x06status\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12\x44\n\x0f\x64\x65nied_response\x18\x02 \x01(\x0b\x32).envoy.service.auth.v2.DeniedHttpResponseH\x00\x12<\n\x0bok_response\x18\x03 \x01(\x0b\x32%.envoy.service.auth.v2.OkHttpResponseH\x00\x42\x0f\n\rhttp_response2e\n\rAuthorization\x12T\n\x05\x43heck\x12#.envoy.service.auth.v2.CheckRequest\x1a$.envoy.service.auth.v2.CheckResponse\"\x00\x42\x45\n#io.envoyproxy.envoy.service.auth.v2B\x11\x45xternalAuthProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_service_dot_auth_dot_v2_dot_attribute__context__pb2.DESCRIPTOR,envoy_dot_type_dot_http__status__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CHECKREQUEST = _descriptor.Descriptor(
  name='CheckRequest',
  full_name='envoy.service.auth.v2.CheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='envoy.service.auth.v2.CheckRequest.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=256,
  serialized_end=331,
)


_DENIEDHTTPRESPONSE = _descriptor.Descriptor(
  name='DeniedHttpResponse',
  full_name='envoy.service.auth.v2.DeniedHttpResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.auth.v2.DeniedHttpResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.auth.v2.DeniedHttpResponse.headers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='envoy.service.auth.v2.DeniedHttpResponse.body', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=473,
)


_OKHTTPRESPONSE = _descriptor.Descriptor(
  name='OkHttpResponse',
  full_name='envoy.service.auth.v2.OkHttpResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.service.auth.v2.OkHttpResponse.headers', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=546,
)


_CHECKRESPONSE = _descriptor.Descriptor(
  name='CheckResponse',
  full_name='envoy.service.auth.v2.CheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='envoy.service.auth.v2.CheckResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denied_response', full_name='envoy.service.auth.v2.CheckResponse.denied_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ok_response', full_name='envoy.service.auth.v2.CheckResponse.ok_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='http_response', full_name='envoy.service.auth.v2.CheckResponse.http_response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=549,
  serialized_end=749,
)

_CHECKREQUEST.fields_by_name['attributes'].message_type = envoy_dot_service_dot_auth_dot_v2_dot_attribute__context__pb2._ATTRIBUTECONTEXT
_DENIEDHTTPRESPONSE.fields_by_name['status'].message_type = envoy_dot_type_dot_http__status__pb2._HTTPSTATUS
_DENIEDHTTPRESPONSE.fields_by_name['headers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUEOPTION
_OKHTTPRESPONSE.fields_by_name['headers'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._HEADERVALUEOPTION
_CHECKRESPONSE.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_CHECKRESPONSE.fields_by_name['denied_response'].message_type = _DENIEDHTTPRESPONSE
_CHECKRESPONSE.fields_by_name['ok_response'].message_type = _OKHTTPRESPONSE
_CHECKRESPONSE.oneofs_by_name['http_response'].fields.append(
  _CHECKRESPONSE.fields_by_name['denied_response'])
_CHECKRESPONSE.fields_by_name['denied_response'].containing_oneof = _CHECKRESPONSE.oneofs_by_name['http_response']
_CHECKRESPONSE.oneofs_by_name['http_response'].fields.append(
  _CHECKRESPONSE.fields_by_name['ok_response'])
_CHECKRESPONSE.fields_by_name['ok_response'].containing_oneof = _CHECKRESPONSE.oneofs_by_name['http_response']
DESCRIPTOR.message_types_by_name['CheckRequest'] = _CHECKREQUEST
DESCRIPTOR.message_types_by_name['DeniedHttpResponse'] = _DENIEDHTTPRESPONSE
DESCRIPTOR.message_types_by_name['OkHttpResponse'] = _OKHTTPRESPONSE
DESCRIPTOR.message_types_by_name['CheckResponse'] = _CHECKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CheckRequest = _reflection.GeneratedProtocolMessageType('CheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKREQUEST,
  '__module__' : 'envoy.service.auth.v2.external_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v2.CheckRequest)
  })
_sym_db.RegisterMessage(CheckRequest)

DeniedHttpResponse = _reflection.GeneratedProtocolMessageType('DeniedHttpResponse', (_message.Message,), {
  'DESCRIPTOR' : _DENIEDHTTPRESPONSE,
  '__module__' : 'envoy.service.auth.v2.external_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v2.DeniedHttpResponse)
  })
_sym_db.RegisterMessage(DeniedHttpResponse)

OkHttpResponse = _reflection.GeneratedProtocolMessageType('OkHttpResponse', (_message.Message,), {
  'DESCRIPTOR' : _OKHTTPRESPONSE,
  '__module__' : 'envoy.service.auth.v2.external_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v2.OkHttpResponse)
  })
_sym_db.RegisterMessage(OkHttpResponse)

CheckResponse = _reflection.GeneratedProtocolMessageType('CheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKRESPONSE,
  '__module__' : 'envoy.service.auth.v2.external_auth_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.auth.v2.CheckResponse)
  })
_sym_db.RegisterMessage(CheckResponse)


DESCRIPTOR._options = None
_DENIEDHTTPRESPONSE.fields_by_name['status']._options = None

_AUTHORIZATION = _descriptor.ServiceDescriptor(
  name='Authorization',
  full_name='envoy.service.auth.v2.Authorization',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=751,
  serialized_end=852,
  methods=[
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='envoy.service.auth.v2.Authorization.Check',
    index=0,
    containing_service=None,
    input_type=_CHECKREQUEST,
    output_type=_CHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTHORIZATION)

DESCRIPTOR.services_by_name['Authorization'] = _AUTHORIZATION

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/service/orca/v1/orca.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.data.orca.v1 import orca_load_report_pb2 as udpa_dot_data_dot_orca_dot_v1_dot_orca__load__report__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='udpa/service/orca/v1/orca.proto',
  package='udpa.service.orca.v1',
  syntax='proto3',
  serialized_options=b'\n$com.github.udpa.udpa.service.orca.v1B\tOrcaProtoP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fudpa/service/orca/v1/orca.proto\x12\x14udpa.service.orca.v1\x1a(udpa/data/orca/v1/orca_load_report.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\"g\n\x15OrcaLoadReportRequest\x12\x32\n\x0freport_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1a\n\x12request_cost_names\x18\x02 \x03(\t2w\n\x0eOpenRcaService\x12\x65\n\x11StreamCoreMetrics\x12+.udpa.service.orca.v1.OrcaLoadReportRequest\x1a!.udpa.data.orca.v1.OrcaLoadReport0\x01\x42\x33\n$com.github.udpa.udpa.service.orca.v1B\tOrcaProtoP\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_data_dot_orca_dot_v1_dot_orca__load__report__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ORCALOADREPORTREQUEST = _descriptor.Descriptor(
  name='OrcaLoadReportRequest',
  full_name='udpa.service.orca.v1.OrcaLoadReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='report_interval', full_name='udpa.service.orca.v1.OrcaLoadReportRequest.report_interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_cost_names', full_name='udpa.service.orca.v1.OrcaLoadReportRequest.request_cost_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=259,
)

_ORCALOADREPORTREQUEST.fields_by_name['report_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['OrcaLoadReportRequest'] = _ORCALOADREPORTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OrcaLoadReportRequest = _reflection.GeneratedProtocolMessageType('OrcaLoadReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORCALOADREPORTREQUEST,
  '__module__' : 'udpa.service.orca.v1.orca_pb2'
  # @@protoc_insertion_point(class_scope:udpa.service.orca.v1.OrcaLoadReportRequest)
  })
_sym_db.RegisterMessage(OrcaLoadReportRequest)


DESCRIPTOR._options = None

_OPENRCASERVICE = _descriptor.ServiceDescriptor(
  name='OpenRcaService',
  full_name='udpa.service.orca.v1.OpenRcaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=261,
  serialized_end=380,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamCoreMetrics',
    full_name='udpa.service.orca.v1.OpenRcaService.StreamCoreMetrics',
    index=0,
    containing_service=None,
    input_type=_ORCALOADREPORTREQUEST,
    output_type=udpa_dot_data_dot_orca_dot_v1_dot_orca__load__report__pb2._ORCALOADREPORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPENRCASERVICE)

DESCRIPTOR.services_by_name['OpenRcaService'] = _OPENRCASERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/extension/v3/config_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/extension/v3/config_discovery.proto',
  package='envoy.service.extension.v3',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.extension.v3B\024ConfigDiscoveryProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1envoy/service/extension/v3/config_discovery.proto\x12\x1a\x65nvoy.service.extension.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\"\x0b\n\tEcdsDummy2\x81\x04\n\x1f\x45xtensionConfigDiscoveryService\x12{\n\x16StreamExtensionConfigs\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x84\x01\n\x15\x44\x65ltaExtensionConfigs\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\xa6\x01\n\x15\x46\x65tchExtensionConfigs\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"0\x82\xd3\xe4\x93\x02!\"\x1f/v3/discovery:extension_configs\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\x31\x8a\xa4\x96\xf3\x07+\n)envoy.config.core.v3.TypedExtensionConfigBM\n(io.envoyproxy.envoy.service.extension.v3B\x14\x43onfigDiscoveryProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_ECDSDUMMY = _descriptor.Descriptor(
  name='EcdsDummy',
  full_name='envoy.service.extension.v3.EcdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=231,
)

DESCRIPTOR.message_types_by_name['EcdsDummy'] = _ECDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EcdsDummy = _reflection.GeneratedProtocolMessageType('EcdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _ECDSDUMMY,
  '__module__' : 'envoy.service.extension.v3.config_discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.extension.v3.EcdsDummy)
  })
_sym_db.RegisterMessage(EcdsDummy)


DESCRIPTOR._options = None

_EXTENSIONCONFIGDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ExtensionConfigDiscoveryService',
  full_name='envoy.service.extension.v3.ExtensionConfigDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007+\n)envoy.config.core.v3.TypedExtensionConfig',
  create_key=_descriptor._internal_create_key,
  serialized_start=234,
  serialized_end=747,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamExtensionConfigs',
    full_name='envoy.service.extension.v3.ExtensionConfigDiscoveryService.StreamExtensionConfigs',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaExtensionConfigs',
    full_name='envoy.service.extension.v3.ExtensionConfigDiscoveryService.DeltaExtensionConfigs',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchExtensionConfigs',
    full_name='envoy.service.extension.v3.ExtensionConfigDiscoveryService.FetchExtensionConfigs',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\037/v3/discovery:extension_configs\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXTENSIONCONFIGDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ExtensionConfigDiscoveryService'] = _EXTENSIONCONFIGDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
